# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class ResponseWorkspaceDetail(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'backup_volume_id': 'int',
        'created_by': 'ResponseUser',
        'created_dt': 'datetime',
        'end_dt': 'datetime',
        'endpoints': 'ResponseWorkloadEndpoints',
        'exit_code': 'int',
        'histories': 'list[ResponseWorkloadHistoryInfo]',
        'id': 'int',
        'idle_shutdown_minutes': 'int',
        'init_script': 'str',
        'kernel_cluster': 'ResponseKernelCluster',
        'kernel_cluster_node': 'ResponseKernelClusterNode',
        'kernel_cluster_select_policies': 'OrmKernelClusterSelectPolicies',
        'kernel_image': 'ResponseKernelImage',
        'kernel_resource_spec': 'ResponseKernelResourceSpec',
        'kubernetes_resource_info': 'ResponseKubernetesResourceInfo',
        'last_backup': 'ResponseWorkspaceBackup',
        'last_backup_succeeded': 'bool',
        'max_running_hours': 'int',
        'name': 'str',
        'organization': 'ResponseOrganization',
        'ports': 'OrmWorkspacePorts',
        'scheduled_termination_dt': 'datetime',
        'service_account_name': 'str',
        'start_command': 'str',
        'status': 'str',
        'status_last_updated': 'datetime',
        'status_reason': 'str',
        'updated_dt': 'datetime',
        'volume_mounts': 'ResponseVolumeMountInfos',
        'volume_v2_mounts': 'ResponseLegacyWorkloadVolumeV2Mounts'
    }

    attribute_map = {
        'backup_volume_id': 'backup_volume_id',
        'created_by': 'created_by',
        'created_dt': 'created_dt',
        'end_dt': 'end_dt',
        'endpoints': 'endpoints',
        'exit_code': 'exit_code',
        'histories': 'histories',
        'id': 'id',
        'idle_shutdown_minutes': 'idle_shutdown_minutes',
        'init_script': 'init_script',
        'kernel_cluster': 'kernel_cluster',
        'kernel_cluster_node': 'kernel_cluster_node',
        'kernel_cluster_select_policies': 'kernel_cluster_select_policies',
        'kernel_image': 'kernel_image',
        'kernel_resource_spec': 'kernel_resource_spec',
        'kubernetes_resource_info': 'kubernetes_resource_info',
        'last_backup': 'last_backup',
        'last_backup_succeeded': 'last_backup_succeeded',
        'max_running_hours': 'max_running_hours',
        'name': 'name',
        'organization': 'organization',
        'ports': 'ports',
        'scheduled_termination_dt': 'scheduled_termination_dt',
        'service_account_name': 'service_account_name',
        'start_command': 'start_command',
        'status': 'status',
        'status_last_updated': 'status_last_updated',
        'status_reason': 'status_reason',
        'updated_dt': 'updated_dt',
        'volume_mounts': 'volume_mounts',
        'volume_v2_mounts': 'volume_v2_mounts'
    }

    def __init__(self, backup_volume_id=None, created_by=None, created_dt=None, end_dt=None, endpoints=None, exit_code=None, histories=None, id=None, idle_shutdown_minutes=None, init_script=None, kernel_cluster=None, kernel_cluster_node=None, kernel_cluster_select_policies=None, kernel_image=None, kernel_resource_spec=None, kubernetes_resource_info=None, last_backup=None, last_backup_succeeded=None, max_running_hours=None, name=None, organization=None, ports=None, scheduled_termination_dt=None, service_account_name=None, start_command=None, status=None, status_last_updated=None, status_reason=None, updated_dt=None, volume_mounts=None, volume_v2_mounts=None, local_vars_configuration=None):  # noqa: E501
        """ResponseWorkspaceDetail - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._backup_volume_id = None
        self._created_by = None
        self._created_dt = None
        self._end_dt = None
        self._endpoints = None
        self._exit_code = None
        self._histories = None
        self._id = None
        self._idle_shutdown_minutes = None
        self._init_script = None
        self._kernel_cluster = None
        self._kernel_cluster_node = None
        self._kernel_cluster_select_policies = None
        self._kernel_image = None
        self._kernel_resource_spec = None
        self._kubernetes_resource_info = None
        self._last_backup = None
        self._last_backup_succeeded = None
        self._max_running_hours = None
        self._name = None
        self._organization = None
        self._ports = None
        self._scheduled_termination_dt = None
        self._service_account_name = None
        self._start_command = None
        self._status = None
        self._status_last_updated = None
        self._status_reason = None
        self._updated_dt = None
        self._volume_mounts = None
        self._volume_v2_mounts = None
        self.discriminator = None

        self.backup_volume_id = backup_volume_id
        self.created_by = created_by
        if created_dt is not None:
            self.created_dt = created_dt
        self.end_dt = end_dt
        if endpoints is not None:
            self.endpoints = endpoints
        self.exit_code = exit_code
        self.histories = histories
        self.id = id
        if idle_shutdown_minutes is not None:
            self.idle_shutdown_minutes = idle_shutdown_minutes
        self.init_script = init_script
        if kernel_cluster is not None:
            self.kernel_cluster = kernel_cluster
        if kernel_cluster_node is not None:
            self.kernel_cluster_node = kernel_cluster_node
        self.kernel_cluster_select_policies = kernel_cluster_select_policies
        self.kernel_image = kernel_image
        self.kernel_resource_spec = kernel_resource_spec
        if kubernetes_resource_info is not None:
            self.kubernetes_resource_info = kubernetes_resource_info
        if last_backup is not None:
            self.last_backup = last_backup
        self.last_backup_succeeded = last_backup_succeeded
        if max_running_hours is not None:
            self.max_running_hours = max_running_hours
        self.name = name
        self.organization = organization
        if ports is not None:
            self.ports = ports
        self.scheduled_termination_dt = scheduled_termination_dt
        if service_account_name is not None:
            self.service_account_name = service_account_name
        self.start_command = start_command
        self.status = status
        self.status_last_updated = status_last_updated
        self.status_reason = status_reason
        if updated_dt is not None:
            self.updated_dt = updated_dt
        if volume_mounts is not None:
            self.volume_mounts = volume_mounts
        if volume_v2_mounts is not None:
            self.volume_v2_mounts = volume_v2_mounts

    @property
    def backup_volume_id(self):
        """Gets the backup_volume_id of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The backup_volume_id of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: int
        """
        return self._backup_volume_id

    @backup_volume_id.setter
    def backup_volume_id(self, backup_volume_id):
        """Sets the backup_volume_id of this ResponseWorkspaceDetail.


        :param backup_volume_id: The backup_volume_id of this ResponseWorkspaceDetail.  # noqa: E501
        :type backup_volume_id: int
        """
        if self.local_vars_configuration.client_side_validation and backup_volume_id is None:  # noqa: E501
            raise ValueError("Invalid value for `backup_volume_id`, must not be `None`")  # noqa: E501

        self._backup_volume_id = backup_volume_id

    @property
    def created_by(self):
        """Gets the created_by of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The created_by of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: ResponseUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ResponseWorkspaceDetail.


        :param created_by: The created_by of this ResponseWorkspaceDetail.  # noqa: E501
        :type created_by: ResponseUser
        """
        if self.local_vars_configuration.client_side_validation and created_by is None:  # noqa: E501
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def created_dt(self):
        """Gets the created_dt of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The created_dt of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ResponseWorkspaceDetail.


        :param created_dt: The created_dt of this ResponseWorkspaceDetail.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def end_dt(self):
        """Gets the end_dt of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The end_dt of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._end_dt

    @end_dt.setter
    def end_dt(self, end_dt):
        """Sets the end_dt of this ResponseWorkspaceDetail.


        :param end_dt: The end_dt of this ResponseWorkspaceDetail.  # noqa: E501
        :type end_dt: datetime
        """

        self._end_dt = end_dt

    @property
    def endpoints(self):
        """Gets the endpoints of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The endpoints of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: ResponseWorkloadEndpoints
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """Sets the endpoints of this ResponseWorkspaceDetail.


        :param endpoints: The endpoints of this ResponseWorkspaceDetail.  # noqa: E501
        :type endpoints: ResponseWorkloadEndpoints
        """

        self._endpoints = endpoints

    @property
    def exit_code(self):
        """Gets the exit_code of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The exit_code of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: int
        """
        return self._exit_code

    @exit_code.setter
    def exit_code(self, exit_code):
        """Sets the exit_code of this ResponseWorkspaceDetail.


        :param exit_code: The exit_code of this ResponseWorkspaceDetail.  # noqa: E501
        :type exit_code: int
        """

        self._exit_code = exit_code

    @property
    def histories(self):
        """Gets the histories of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The histories of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: list[ResponseWorkloadHistoryInfo]
        """
        return self._histories

    @histories.setter
    def histories(self, histories):
        """Sets the histories of this ResponseWorkspaceDetail.


        :param histories: The histories of this ResponseWorkspaceDetail.  # noqa: E501
        :type histories: list[ResponseWorkloadHistoryInfo]
        """
        if self.local_vars_configuration.client_side_validation and histories is None:  # noqa: E501
            raise ValueError("Invalid value for `histories`, must not be `None`")  # noqa: E501

        self._histories = histories

    @property
    def id(self):
        """Gets the id of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The id of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseWorkspaceDetail.


        :param id: The id of this ResponseWorkspaceDetail.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def idle_shutdown_minutes(self):
        """Gets the idle_shutdown_minutes of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The idle_shutdown_minutes of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: int
        """
        return self._idle_shutdown_minutes

    @idle_shutdown_minutes.setter
    def idle_shutdown_minutes(self, idle_shutdown_minutes):
        """Sets the idle_shutdown_minutes of this ResponseWorkspaceDetail.


        :param idle_shutdown_minutes: The idle_shutdown_minutes of this ResponseWorkspaceDetail.  # noqa: E501
        :type idle_shutdown_minutes: int
        """

        self._idle_shutdown_minutes = idle_shutdown_minutes

    @property
    def init_script(self):
        """Gets the init_script of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The init_script of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: str
        """
        return self._init_script

    @init_script.setter
    def init_script(self, init_script):
        """Sets the init_script of this ResponseWorkspaceDetail.


        :param init_script: The init_script of this ResponseWorkspaceDetail.  # noqa: E501
        :type init_script: str
        """

        self._init_script = init_script

    @property
    def kernel_cluster(self):
        """Gets the kernel_cluster of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The kernel_cluster of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: ResponseKernelCluster
        """
        return self._kernel_cluster

    @kernel_cluster.setter
    def kernel_cluster(self, kernel_cluster):
        """Sets the kernel_cluster of this ResponseWorkspaceDetail.


        :param kernel_cluster: The kernel_cluster of this ResponseWorkspaceDetail.  # noqa: E501
        :type kernel_cluster: ResponseKernelCluster
        """

        self._kernel_cluster = kernel_cluster

    @property
    def kernel_cluster_node(self):
        """Gets the kernel_cluster_node of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The kernel_cluster_node of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: ResponseKernelClusterNode
        """
        return self._kernel_cluster_node

    @kernel_cluster_node.setter
    def kernel_cluster_node(self, kernel_cluster_node):
        """Sets the kernel_cluster_node of this ResponseWorkspaceDetail.


        :param kernel_cluster_node: The kernel_cluster_node of this ResponseWorkspaceDetail.  # noqa: E501
        :type kernel_cluster_node: ResponseKernelClusterNode
        """

        self._kernel_cluster_node = kernel_cluster_node

    @property
    def kernel_cluster_select_policies(self):
        """Gets the kernel_cluster_select_policies of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The kernel_cluster_select_policies of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: OrmKernelClusterSelectPolicies
        """
        return self._kernel_cluster_select_policies

    @kernel_cluster_select_policies.setter
    def kernel_cluster_select_policies(self, kernel_cluster_select_policies):
        """Sets the kernel_cluster_select_policies of this ResponseWorkspaceDetail.


        :param kernel_cluster_select_policies: The kernel_cluster_select_policies of this ResponseWorkspaceDetail.  # noqa: E501
        :type kernel_cluster_select_policies: OrmKernelClusterSelectPolicies
        """
        if self.local_vars_configuration.client_side_validation and kernel_cluster_select_policies is None:  # noqa: E501
            raise ValueError("Invalid value for `kernel_cluster_select_policies`, must not be `None`")  # noqa: E501

        self._kernel_cluster_select_policies = kernel_cluster_select_policies

    @property
    def kernel_image(self):
        """Gets the kernel_image of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The kernel_image of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: ResponseKernelImage
        """
        return self._kernel_image

    @kernel_image.setter
    def kernel_image(self, kernel_image):
        """Sets the kernel_image of this ResponseWorkspaceDetail.


        :param kernel_image: The kernel_image of this ResponseWorkspaceDetail.  # noqa: E501
        :type kernel_image: ResponseKernelImage
        """
        if self.local_vars_configuration.client_side_validation and kernel_image is None:  # noqa: E501
            raise ValueError("Invalid value for `kernel_image`, must not be `None`")  # noqa: E501

        self._kernel_image = kernel_image

    @property
    def kernel_resource_spec(self):
        """Gets the kernel_resource_spec of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The kernel_resource_spec of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: ResponseKernelResourceSpec
        """
        return self._kernel_resource_spec

    @kernel_resource_spec.setter
    def kernel_resource_spec(self, kernel_resource_spec):
        """Sets the kernel_resource_spec of this ResponseWorkspaceDetail.


        :param kernel_resource_spec: The kernel_resource_spec of this ResponseWorkspaceDetail.  # noqa: E501
        :type kernel_resource_spec: ResponseKernelResourceSpec
        """
        if self.local_vars_configuration.client_side_validation and kernel_resource_spec is None:  # noqa: E501
            raise ValueError("Invalid value for `kernel_resource_spec`, must not be `None`")  # noqa: E501

        self._kernel_resource_spec = kernel_resource_spec

    @property
    def kubernetes_resource_info(self):
        """Gets the kubernetes_resource_info of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The kubernetes_resource_info of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: ResponseKubernetesResourceInfo
        """
        return self._kubernetes_resource_info

    @kubernetes_resource_info.setter
    def kubernetes_resource_info(self, kubernetes_resource_info):
        """Sets the kubernetes_resource_info of this ResponseWorkspaceDetail.


        :param kubernetes_resource_info: The kubernetes_resource_info of this ResponseWorkspaceDetail.  # noqa: E501
        :type kubernetes_resource_info: ResponseKubernetesResourceInfo
        """

        self._kubernetes_resource_info = kubernetes_resource_info

    @property
    def last_backup(self):
        """Gets the last_backup of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The last_backup of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: ResponseWorkspaceBackup
        """
        return self._last_backup

    @last_backup.setter
    def last_backup(self, last_backup):
        """Sets the last_backup of this ResponseWorkspaceDetail.


        :param last_backup: The last_backup of this ResponseWorkspaceDetail.  # noqa: E501
        :type last_backup: ResponseWorkspaceBackup
        """

        self._last_backup = last_backup

    @property
    def last_backup_succeeded(self):
        """Gets the last_backup_succeeded of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The last_backup_succeeded of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: bool
        """
        return self._last_backup_succeeded

    @last_backup_succeeded.setter
    def last_backup_succeeded(self, last_backup_succeeded):
        """Sets the last_backup_succeeded of this ResponseWorkspaceDetail.


        :param last_backup_succeeded: The last_backup_succeeded of this ResponseWorkspaceDetail.  # noqa: E501
        :type last_backup_succeeded: bool
        """

        self._last_backup_succeeded = last_backup_succeeded

    @property
    def max_running_hours(self):
        """Gets the max_running_hours of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The max_running_hours of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: int
        """
        return self._max_running_hours

    @max_running_hours.setter
    def max_running_hours(self, max_running_hours):
        """Sets the max_running_hours of this ResponseWorkspaceDetail.


        :param max_running_hours: The max_running_hours of this ResponseWorkspaceDetail.  # noqa: E501
        :type max_running_hours: int
        """

        self._max_running_hours = max_running_hours

    @property
    def name(self):
        """Gets the name of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The name of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ResponseWorkspaceDetail.


        :param name: The name of this ResponseWorkspaceDetail.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def organization(self):
        """Gets the organization of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The organization of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: ResponseOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this ResponseWorkspaceDetail.


        :param organization: The organization of this ResponseWorkspaceDetail.  # noqa: E501
        :type organization: ResponseOrganization
        """
        if self.local_vars_configuration.client_side_validation and organization is None:  # noqa: E501
            raise ValueError("Invalid value for `organization`, must not be `None`")  # noqa: E501

        self._organization = organization

    @property
    def ports(self):
        """Gets the ports of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The ports of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: OrmWorkspacePorts
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this ResponseWorkspaceDetail.


        :param ports: The ports of this ResponseWorkspaceDetail.  # noqa: E501
        :type ports: OrmWorkspacePorts
        """

        self._ports = ports

    @property
    def scheduled_termination_dt(self):
        """Gets the scheduled_termination_dt of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The scheduled_termination_dt of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._scheduled_termination_dt

    @scheduled_termination_dt.setter
    def scheduled_termination_dt(self, scheduled_termination_dt):
        """Sets the scheduled_termination_dt of this ResponseWorkspaceDetail.


        :param scheduled_termination_dt: The scheduled_termination_dt of this ResponseWorkspaceDetail.  # noqa: E501
        :type scheduled_termination_dt: datetime
        """

        self._scheduled_termination_dt = scheduled_termination_dt

    @property
    def service_account_name(self):
        """Gets the service_account_name of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The service_account_name of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: str
        """
        return self._service_account_name

    @service_account_name.setter
    def service_account_name(self, service_account_name):
        """Sets the service_account_name of this ResponseWorkspaceDetail.


        :param service_account_name: The service_account_name of this ResponseWorkspaceDetail.  # noqa: E501
        :type service_account_name: str
        """

        self._service_account_name = service_account_name

    @property
    def start_command(self):
        """Gets the start_command of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The start_command of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: str
        """
        return self._start_command

    @start_command.setter
    def start_command(self, start_command):
        """Sets the start_command of this ResponseWorkspaceDetail.


        :param start_command: The start_command of this ResponseWorkspaceDetail.  # noqa: E501
        :type start_command: str
        """

        self._start_command = start_command

    @property
    def status(self):
        """Gets the status of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The status of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponseWorkspaceDetail.


        :param status: The status of this ResponseWorkspaceDetail.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def status_last_updated(self):
        """Gets the status_last_updated of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The status_last_updated of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._status_last_updated

    @status_last_updated.setter
    def status_last_updated(self, status_last_updated):
        """Sets the status_last_updated of this ResponseWorkspaceDetail.


        :param status_last_updated: The status_last_updated of this ResponseWorkspaceDetail.  # noqa: E501
        :type status_last_updated: datetime
        """
        if self.local_vars_configuration.client_side_validation and status_last_updated is None:  # noqa: E501
            raise ValueError("Invalid value for `status_last_updated`, must not be `None`")  # noqa: E501

        self._status_last_updated = status_last_updated

    @property
    def status_reason(self):
        """Gets the status_reason of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The status_reason of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: str
        """
        return self._status_reason

    @status_reason.setter
    def status_reason(self, status_reason):
        """Sets the status_reason of this ResponseWorkspaceDetail.


        :param status_reason: The status_reason of this ResponseWorkspaceDetail.  # noqa: E501
        :type status_reason: str
        """
        if self.local_vars_configuration.client_side_validation and status_reason is None:  # noqa: E501
            raise ValueError("Invalid value for `status_reason`, must not be `None`")  # noqa: E501

        self._status_reason = status_reason

    @property
    def updated_dt(self):
        """Gets the updated_dt of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The updated_dt of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this ResponseWorkspaceDetail.


        :param updated_dt: The updated_dt of this ResponseWorkspaceDetail.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def volume_mounts(self):
        """Gets the volume_mounts of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The volume_mounts of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: ResponseVolumeMountInfos
        """
        return self._volume_mounts

    @volume_mounts.setter
    def volume_mounts(self, volume_mounts):
        """Sets the volume_mounts of this ResponseWorkspaceDetail.


        :param volume_mounts: The volume_mounts of this ResponseWorkspaceDetail.  # noqa: E501
        :type volume_mounts: ResponseVolumeMountInfos
        """

        self._volume_mounts = volume_mounts

    @property
    def volume_v2_mounts(self):
        """Gets the volume_v2_mounts of this ResponseWorkspaceDetail.  # noqa: E501


        :return: The volume_v2_mounts of this ResponseWorkspaceDetail.  # noqa: E501
        :rtype: ResponseLegacyWorkloadVolumeV2Mounts
        """
        return self._volume_v2_mounts

    @volume_v2_mounts.setter
    def volume_v2_mounts(self, volume_v2_mounts):
        """Sets the volume_v2_mounts of this ResponseWorkspaceDetail.


        :param volume_v2_mounts: The volume_v2_mounts of this ResponseWorkspaceDetail.  # noqa: E501
        :type volume_v2_mounts: ResponseLegacyWorkloadVolumeV2Mounts
        """

        self._volume_v2_mounts = volume_v2_mounts

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWorkspaceDetail):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseWorkspaceDetail):
            return True

        return self.to_dict() != other.to_dict()



import os


def ensure_parent_dir_exists(path_to_file: str):
    """
    Given a path to a file, ensure that its parent directory exists,
    creating directories (throughout the hierarchy) if needed.

    Example:
        ensure_parent_dir_exists("./dir1/dir2/file")
        : Ensure that the directory "./dir1/dir2/" exists.

        ensure_parent_dir_exists("/code/mymodel/README.md")
        : Ensure that the directory "/code/mymodel/" exists.

        ensure_parent_dir_exists("path.py")
        : Does nothing.
    """

    dirname = os.path.dirname(path_to_file)
    if dirname != "":
        os.makedirs(dirname, exist_ok=True)



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class OrmArtifact(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'artifact_created_by': 'int',
        'artifact_organization': 'int',
        'artifact_origin': 'int',
        'artifact_run_execution': 'int',
        'artifact_workload': 'int',
        'claim_name': 'str',
        'created_dt': 'datetime',
        'description': 'str',
        'edges': 'OrmArtifactEdges',
        'id': 'int',
        'immutable_slug': 'str',
        'is_plot_artifact': 'bool',
        'name': 'str',
        'parent_artifact_id': 'int',
        'storage_config': 'dict[str, object]',
        'storage_type': 'str',
        'sub_path': 'str',
        'type': 'str',
        'updated_dt': 'datetime'
    }

    attribute_map = {
        'artifact_created_by': 'artifact_created_by',
        'artifact_organization': 'artifact_organization',
        'artifact_origin': 'artifact_origin',
        'artifact_run_execution': 'artifact_run_execution',
        'artifact_workload': 'artifact_workload',
        'claim_name': 'claim_name',
        'created_dt': 'created_dt',
        'description': 'description',
        'edges': 'edges',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'is_plot_artifact': 'is_plot_artifact',
        'name': 'name',
        'parent_artifact_id': 'parent_artifact_id',
        'storage_config': 'storage_config',
        'storage_type': 'storage_type',
        'sub_path': 'sub_path',
        'type': 'type',
        'updated_dt': 'updated_dt'
    }

    def __init__(self, artifact_created_by=None, artifact_organization=None, artifact_origin=None, artifact_run_execution=None, artifact_workload=None, claim_name=None, created_dt=None, description=None, edges=None, id=None, immutable_slug=None, is_plot_artifact=None, name=None, parent_artifact_id=None, storage_config=None, storage_type=None, sub_path=None, type=None, updated_dt=None, local_vars_configuration=None):  # noqa: E501
        """OrmArtifact - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._artifact_created_by = None
        self._artifact_organization = None
        self._artifact_origin = None
        self._artifact_run_execution = None
        self._artifact_workload = None
        self._claim_name = None
        self._created_dt = None
        self._description = None
        self._edges = None
        self._id = None
        self._immutable_slug = None
        self._is_plot_artifact = None
        self._name = None
        self._parent_artifact_id = None
        self._storage_config = None
        self._storage_type = None
        self._sub_path = None
        self._type = None
        self._updated_dt = None
        self.discriminator = None

        self.artifact_created_by = artifact_created_by
        if artifact_organization is not None:
            self.artifact_organization = artifact_organization
        self.artifact_origin = artifact_origin
        self.artifact_run_execution = artifact_run_execution
        self.artifact_workload = artifact_workload
        self.claim_name = claim_name
        if created_dt is not None:
            self.created_dt = created_dt
        self.description = description
        if edges is not None:
            self.edges = edges
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        if is_plot_artifact is not None:
            self.is_plot_artifact = is_plot_artifact
        self.name = name
        self.parent_artifact_id = parent_artifact_id
        if storage_config is not None:
            self.storage_config = storage_config
        self.storage_type = storage_type
        if sub_path is not None:
            self.sub_path = sub_path
        if type is not None:
            self.type = type
        if updated_dt is not None:
            self.updated_dt = updated_dt

    @property
    def artifact_created_by(self):
        """Gets the artifact_created_by of this OrmArtifact.  # noqa: E501


        :return: The artifact_created_by of this OrmArtifact.  # noqa: E501
        :rtype: int
        """
        return self._artifact_created_by

    @artifact_created_by.setter
    def artifact_created_by(self, artifact_created_by):
        """Sets the artifact_created_by of this OrmArtifact.


        :param artifact_created_by: The artifact_created_by of this OrmArtifact.  # noqa: E501
        :type artifact_created_by: int
        """

        self._artifact_created_by = artifact_created_by

    @property
    def artifact_organization(self):
        """Gets the artifact_organization of this OrmArtifact.  # noqa: E501


        :return: The artifact_organization of this OrmArtifact.  # noqa: E501
        :rtype: int
        """
        return self._artifact_organization

    @artifact_organization.setter
    def artifact_organization(self, artifact_organization):
        """Sets the artifact_organization of this OrmArtifact.


        :param artifact_organization: The artifact_organization of this OrmArtifact.  # noqa: E501
        :type artifact_organization: int
        """

        self._artifact_organization = artifact_organization

    @property
    def artifact_origin(self):
        """Gets the artifact_origin of this OrmArtifact.  # noqa: E501


        :return: The artifact_origin of this OrmArtifact.  # noqa: E501
        :rtype: int
        """
        return self._artifact_origin

    @artifact_origin.setter
    def artifact_origin(self, artifact_origin):
        """Sets the artifact_origin of this OrmArtifact.


        :param artifact_origin: The artifact_origin of this OrmArtifact.  # noqa: E501
        :type artifact_origin: int
        """

        self._artifact_origin = artifact_origin

    @property
    def artifact_run_execution(self):
        """Gets the artifact_run_execution of this OrmArtifact.  # noqa: E501


        :return: The artifact_run_execution of this OrmArtifact.  # noqa: E501
        :rtype: int
        """
        return self._artifact_run_execution

    @artifact_run_execution.setter
    def artifact_run_execution(self, artifact_run_execution):
        """Sets the artifact_run_execution of this OrmArtifact.


        :param artifact_run_execution: The artifact_run_execution of this OrmArtifact.  # noqa: E501
        :type artifact_run_execution: int
        """

        self._artifact_run_execution = artifact_run_execution

    @property
    def artifact_workload(self):
        """Gets the artifact_workload of this OrmArtifact.  # noqa: E501


        :return: The artifact_workload of this OrmArtifact.  # noqa: E501
        :rtype: int
        """
        return self._artifact_workload

    @artifact_workload.setter
    def artifact_workload(self, artifact_workload):
        """Sets the artifact_workload of this OrmArtifact.


        :param artifact_workload: The artifact_workload of this OrmArtifact.  # noqa: E501
        :type artifact_workload: int
        """

        self._artifact_workload = artifact_workload

    @property
    def claim_name(self):
        """Gets the claim_name of this OrmArtifact.  # noqa: E501


        :return: The claim_name of this OrmArtifact.  # noqa: E501
        :rtype: str
        """
        return self._claim_name

    @claim_name.setter
    def claim_name(self, claim_name):
        """Sets the claim_name of this OrmArtifact.


        :param claim_name: The claim_name of this OrmArtifact.  # noqa: E501
        :type claim_name: str
        """

        self._claim_name = claim_name

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmArtifact.  # noqa: E501


        :return: The created_dt of this OrmArtifact.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmArtifact.


        :param created_dt: The created_dt of this OrmArtifact.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def description(self):
        """Gets the description of this OrmArtifact.  # noqa: E501


        :return: The description of this OrmArtifact.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this OrmArtifact.


        :param description: The description of this OrmArtifact.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def edges(self):
        """Gets the edges of this OrmArtifact.  # noqa: E501


        :return: The edges of this OrmArtifact.  # noqa: E501
        :rtype: OrmArtifactEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmArtifact.


        :param edges: The edges of this OrmArtifact.  # noqa: E501
        :type edges: OrmArtifactEdges
        """

        self._edges = edges

    @property
    def id(self):
        """Gets the id of this OrmArtifact.  # noqa: E501


        :return: The id of this OrmArtifact.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmArtifact.


        :param id: The id of this OrmArtifact.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this OrmArtifact.  # noqa: E501


        :return: The immutable_slug of this OrmArtifact.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this OrmArtifact.


        :param immutable_slug: The immutable_slug of this OrmArtifact.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def is_plot_artifact(self):
        """Gets the is_plot_artifact of this OrmArtifact.  # noqa: E501


        :return: The is_plot_artifact of this OrmArtifact.  # noqa: E501
        :rtype: bool
        """
        return self._is_plot_artifact

    @is_plot_artifact.setter
    def is_plot_artifact(self, is_plot_artifact):
        """Sets the is_plot_artifact of this OrmArtifact.


        :param is_plot_artifact: The is_plot_artifact of this OrmArtifact.  # noqa: E501
        :type is_plot_artifact: bool
        """

        self._is_plot_artifact = is_plot_artifact

    @property
    def name(self):
        """Gets the name of this OrmArtifact.  # noqa: E501


        :return: The name of this OrmArtifact.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrmArtifact.


        :param name: The name of this OrmArtifact.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def parent_artifact_id(self):
        """Gets the parent_artifact_id of this OrmArtifact.  # noqa: E501


        :return: The parent_artifact_id of this OrmArtifact.  # noqa: E501
        :rtype: int
        """
        return self._parent_artifact_id

    @parent_artifact_id.setter
    def parent_artifact_id(self, parent_artifact_id):
        """Sets the parent_artifact_id of this OrmArtifact.


        :param parent_artifact_id: The parent_artifact_id of this OrmArtifact.  # noqa: E501
        :type parent_artifact_id: int
        """

        self._parent_artifact_id = parent_artifact_id

    @property
    def storage_config(self):
        """Gets the storage_config of this OrmArtifact.  # noqa: E501


        :return: The storage_config of this OrmArtifact.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._storage_config

    @storage_config.setter
    def storage_config(self, storage_config):
        """Sets the storage_config of this OrmArtifact.


        :param storage_config: The storage_config of this OrmArtifact.  # noqa: E501
        :type storage_config: dict[str, object]
        """

        self._storage_config = storage_config

    @property
    def storage_type(self):
        """Gets the storage_type of this OrmArtifact.  # noqa: E501


        :return: The storage_type of this OrmArtifact.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this OrmArtifact.


        :param storage_type: The storage_type of this OrmArtifact.  # noqa: E501
        :type storage_type: str
        """

        self._storage_type = storage_type

    @property
    def sub_path(self):
        """Gets the sub_path of this OrmArtifact.  # noqa: E501


        :return: The sub_path of this OrmArtifact.  # noqa: E501
        :rtype: str
        """
        return self._sub_path

    @sub_path.setter
    def sub_path(self, sub_path):
        """Sets the sub_path of this OrmArtifact.


        :param sub_path: The sub_path of this OrmArtifact.  # noqa: E501
        :type sub_path: str
        """

        self._sub_path = sub_path

    @property
    def type(self):
        """Gets the type of this OrmArtifact.  # noqa: E501


        :return: The type of this OrmArtifact.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OrmArtifact.


        :param type: The type of this OrmArtifact.  # noqa: E501
        :type type: str
        """

        self._type = type

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmArtifact.  # noqa: E501


        :return: The updated_dt of this OrmArtifact.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmArtifact.


        :param updated_dt: The updated_dt of this OrmArtifact.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmArtifact):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmArtifact):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class LLMKnowledgeRetrieverQueryAPIInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'collection_name': 'str',
        'embedding_model': 'LlmEmbeddingModelRequest',
        'prompt': 'str',
        'top_k': 'int',
        'vector_db': 'LlmVectorDBRequest'
    }

    attribute_map = {
        'collection_name': 'collection_name',
        'embedding_model': 'embedding_model',
        'prompt': 'prompt',
        'top_k': 'top_k',
        'vector_db': 'vector_db'
    }

    def __init__(self, collection_name=None, embedding_model=None, prompt=None, top_k=None, vector_db=None, local_vars_configuration=None):  # noqa: E501
        """LLMKnowledgeRetrieverQueryAPIInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._collection_name = None
        self._embedding_model = None
        self._prompt = None
        self._top_k = None
        self._vector_db = None
        self.discriminator = None

        if collection_name is not None:
            self.collection_name = collection_name
        if embedding_model is not None:
            self.embedding_model = embedding_model
        if prompt is not None:
            self.prompt = prompt
        if top_k is not None:
            self.top_k = top_k
        if vector_db is not None:
            self.vector_db = vector_db

    @property
    def collection_name(self):
        """Gets the collection_name of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501


        :return: The collection_name of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._collection_name

    @collection_name.setter
    def collection_name(self, collection_name):
        """Sets the collection_name of this LLMKnowledgeRetrieverQueryAPIInput.


        :param collection_name: The collection_name of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501
        :type collection_name: str
        """

        self._collection_name = collection_name

    @property
    def embedding_model(self):
        """Gets the embedding_model of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501


        :return: The embedding_model of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501
        :rtype: LlmEmbeddingModelRequest
        """
        return self._embedding_model

    @embedding_model.setter
    def embedding_model(self, embedding_model):
        """Sets the embedding_model of this LLMKnowledgeRetrieverQueryAPIInput.


        :param embedding_model: The embedding_model of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501
        :type embedding_model: LlmEmbeddingModelRequest
        """

        self._embedding_model = embedding_model

    @property
    def prompt(self):
        """Gets the prompt of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501


        :return: The prompt of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._prompt

    @prompt.setter
    def prompt(self, prompt):
        """Sets the prompt of this LLMKnowledgeRetrieverQueryAPIInput.


        :param prompt: The prompt of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501
        :type prompt: str
        """

        self._prompt = prompt

    @property
    def top_k(self):
        """Gets the top_k of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501


        :return: The top_k of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._top_k

    @top_k.setter
    def top_k(self, top_k):
        """Sets the top_k of this LLMKnowledgeRetrieverQueryAPIInput.


        :param top_k: The top_k of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501
        :type top_k: int
        """

        self._top_k = top_k

    @property
    def vector_db(self):
        """Gets the vector_db of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501


        :return: The vector_db of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501
        :rtype: LlmVectorDBRequest
        """
        return self._vector_db

    @vector_db.setter
    def vector_db(self, vector_db):
        """Sets the vector_db of this LLMKnowledgeRetrieverQueryAPIInput.


        :param vector_db: The vector_db of this LLMKnowledgeRetrieverQueryAPIInput.  # noqa: E501
        :type vector_db: LlmVectorDBRequest
        """

        self._vector_db = vector_db

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LLMKnowledgeRetrieverQueryAPIInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LLMKnowledgeRetrieverQueryAPIInput):
            return True

        return self.to_dict() != other.to_dict()



import os
import subprocess
import platform
import time
from importlib.metadata import version

from vessl import vessl_api
from vessl.organization import _get_organization_name
from vessl.util.service_pattern import get_hfdiffusers_pattern
from vessl.model import (
    create_model_repository,
    read_model_repository,
    upload_model_volume_file,
)
from vessl.models import VesslModel

class ModelForServiceHFDiffuser(VesslModel):
    @classmethod
    def init(self, model_name_or_path: str = None, repository_name: str = None):
        assert model_name_or_path != None
        assert repository_name != None
        self.model_name_or_path = model_name_or_path
        self.repository_name = repository_name
        self.model_type = "hf-diffusers"

        timestamp = time.time()
        lt = time.localtime(timestamp)
        current_time = time.strftime("%Y%m%d-%H%M%S",lt)
        self.base_path = os.path.join(os.getcwd(), f"vessl_model_{self.model_name_or_path}_{current_time}")
        if not os.path.exists(self.base_path):
            os.makedirs(name = self.base_path)

        entrypoint = "vessl model launch service.py:HfDiffuserRunner -p 3000"
        
        python_version = platform.python_version()

        cuda_version = subprocess.Popen("nvidia-smi -q -x 2>/dev/null | grep cuda_version | awk -F'[><]' '{print $3}'", shell=True, stdout=subprocess.PIPE, encoding='utf8').stdout.read().strip()
        if cuda_version == "":
            print("nvidia-smi command not found: cuda_version will be set into None")
            cuda_version = None
        
        try:
            torch_version = version("torch")
        except:
            torch_version = None
        try:
            tensorflow_version = version("tensorflow")
        except:
            tensorflow_version = None

        # torch version has a higher priority
        framework_type = None
        if tensorflow_version != None:
            framework_type = "tensorflow"
        if torch_version != None:
            framework_type = "torch"

        requirements_path = os.path.join(self.base_path, "requirements.txt")
        if not os.path.exists(requirements_path):
            requirements_path = None
        
        pyproject_path = os.path.join(self.base_path, "pyproject.toml")
        if not os.path.exists(pyproject_path):
            pyproject_path = None

        if requirements_path == None and pyproject_path == None:
            default_hf_transformers_requirements = ["diffusers"]
            requirements_path = os.path.join(self.base_path, "requirements.txt")
            with open(requirements_path, "w") as f:
                for r in default_hf_transformers_requirements:
                    f.write(f"{r}\n")

        model_number = "supplied_when_registering"
        vessl_model = self.create(
            type=self.model_type,
            repository_name=self.repository_name,
            model_number=model_number,
            entrypoint=entrypoint,
            python_version=python_version,
            weight_name_or_path=self.model_name_or_path,
            requirements_path=requirements_path,
            pyproject_path=pyproject_path,
            cuda_version=cuda_version,
            framework_type=framework_type,
            pytorch_version=torch_version,
            tensorflow_version=tensorflow_version,
            autocreate_repository=True,
        )        

        self.create_ignore_file(dest_dir=self.base_path)
        print("Generated ignore file.")
        vessl_model.save_lockfile(dest_dir=self.base_path)
        print("Saved lockfile.")

        # generate service.py
        # it will automatically get model and tokenizer from config json in future
        service_py = get_hfdiffusers_pattern()
        service_py = service_py.format(pipeline_type="DiffusionPipeline", model_name_or_path=f'"{self.model_name_or_path}"')    

        service_dest_path = os.path.join(self.base_path, "service.py")

        if not os.path.exists(service_dest_path):
            with open(service_dest_path, "w") as f:
                f.write(service_py)

        return vessl_model

    def register_model(self, **kwargs):
        if self.model_number == "supplied_when_registering":
            print("Creating a new model.")
            created_model = vessl_api.model_create_api(
                organization_name=_get_organization_name(**kwargs),
                repository_name=self.repository_name,
            )
            model_number = created_model.number
            print(f"Created a new model with number {model_number}.")

        self.model_number = model_number
        self.save_lockfile(self.base_path)
        print("Lockfile saved.")

        try:
            repo = read_model_repository(repository_name=self.repository_name)
        except Exception as e:
            repo = None
        if repo is None:
            create_model_repository(self.repository_name)

        src_path = self.base_path
        print(f"{self.repository_name}-{model_number} {src_path} /")
        upload_model_volume_file(
            repository_name=self.repository_name,
            model_number=model_number,
            source_path=src_path,
            dest_path="/",
        )
        print(f"Registered {self.repository_name}-{model_number}.")



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class OrmModelServiceRevisionEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_token': 'OrmAccessToken',
        'created_by': 'OrmUser',
        'kernel_image': 'OrmKernelImage',
        'llm_workflow_revision': 'OrmLLMWorkflowRevision',
        'model': 'OrmModel',
        'model_service': 'OrmModelService',
        'pod_count_history': 'list[OrmModelServicePodCountHistory]',
        'workload': 'OrmWorkload'
    }

    attribute_map = {
        'access_token': 'access_token',
        'created_by': 'created_by',
        'kernel_image': 'kernel_image',
        'llm_workflow_revision': 'llm_workflow_revision',
        'model': 'model',
        'model_service': 'model_service',
        'pod_count_history': 'pod_count_history',
        'workload': 'workload'
    }

    def __init__(self, access_token=None, created_by=None, kernel_image=None, llm_workflow_revision=None, model=None, model_service=None, pod_count_history=None, workload=None, local_vars_configuration=None):  # noqa: E501
        """OrmModelServiceRevisionEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._access_token = None
        self._created_by = None
        self._kernel_image = None
        self._llm_workflow_revision = None
        self._model = None
        self._model_service = None
        self._pod_count_history = None
        self._workload = None
        self.discriminator = None

        if access_token is not None:
            self.access_token = access_token
        if created_by is not None:
            self.created_by = created_by
        if kernel_image is not None:
            self.kernel_image = kernel_image
        if llm_workflow_revision is not None:
            self.llm_workflow_revision = llm_workflow_revision
        if model is not None:
            self.model = model
        if model_service is not None:
            self.model_service = model_service
        if pod_count_history is not None:
            self.pod_count_history = pod_count_history
        if workload is not None:
            self.workload = workload

    @property
    def access_token(self):
        """Gets the access_token of this OrmModelServiceRevisionEdges.  # noqa: E501


        :return: The access_token of this OrmModelServiceRevisionEdges.  # noqa: E501
        :rtype: OrmAccessToken
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this OrmModelServiceRevisionEdges.


        :param access_token: The access_token of this OrmModelServiceRevisionEdges.  # noqa: E501
        :type access_token: OrmAccessToken
        """

        self._access_token = access_token

    @property
    def created_by(self):
        """Gets the created_by of this OrmModelServiceRevisionEdges.  # noqa: E501


        :return: The created_by of this OrmModelServiceRevisionEdges.  # noqa: E501
        :rtype: OrmUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this OrmModelServiceRevisionEdges.


        :param created_by: The created_by of this OrmModelServiceRevisionEdges.  # noqa: E501
        :type created_by: OrmUser
        """

        self._created_by = created_by

    @property
    def kernel_image(self):
        """Gets the kernel_image of this OrmModelServiceRevisionEdges.  # noqa: E501


        :return: The kernel_image of this OrmModelServiceRevisionEdges.  # noqa: E501
        :rtype: OrmKernelImage
        """
        return self._kernel_image

    @kernel_image.setter
    def kernel_image(self, kernel_image):
        """Sets the kernel_image of this OrmModelServiceRevisionEdges.


        :param kernel_image: The kernel_image of this OrmModelServiceRevisionEdges.  # noqa: E501
        :type kernel_image: OrmKernelImage
        """

        self._kernel_image = kernel_image

    @property
    def llm_workflow_revision(self):
        """Gets the llm_workflow_revision of this OrmModelServiceRevisionEdges.  # noqa: E501


        :return: The llm_workflow_revision of this OrmModelServiceRevisionEdges.  # noqa: E501
        :rtype: OrmLLMWorkflowRevision
        """
        return self._llm_workflow_revision

    @llm_workflow_revision.setter
    def llm_workflow_revision(self, llm_workflow_revision):
        """Sets the llm_workflow_revision of this OrmModelServiceRevisionEdges.


        :param llm_workflow_revision: The llm_workflow_revision of this OrmModelServiceRevisionEdges.  # noqa: E501
        :type llm_workflow_revision: OrmLLMWorkflowRevision
        """

        self._llm_workflow_revision = llm_workflow_revision

    @property
    def model(self):
        """Gets the model of this OrmModelServiceRevisionEdges.  # noqa: E501


        :return: The model of this OrmModelServiceRevisionEdges.  # noqa: E501
        :rtype: OrmModel
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this OrmModelServiceRevisionEdges.


        :param model: The model of this OrmModelServiceRevisionEdges.  # noqa: E501
        :type model: OrmModel
        """

        self._model = model

    @property
    def model_service(self):
        """Gets the model_service of this OrmModelServiceRevisionEdges.  # noqa: E501


        :return: The model_service of this OrmModelServiceRevisionEdges.  # noqa: E501
        :rtype: OrmModelService
        """
        return self._model_service

    @model_service.setter
    def model_service(self, model_service):
        """Sets the model_service of this OrmModelServiceRevisionEdges.


        :param model_service: The model_service of this OrmModelServiceRevisionEdges.  # noqa: E501
        :type model_service: OrmModelService
        """

        self._model_service = model_service

    @property
    def pod_count_history(self):
        """Gets the pod_count_history of this OrmModelServiceRevisionEdges.  # noqa: E501


        :return: The pod_count_history of this OrmModelServiceRevisionEdges.  # noqa: E501
        :rtype: list[OrmModelServicePodCountHistory]
        """
        return self._pod_count_history

    @pod_count_history.setter
    def pod_count_history(self, pod_count_history):
        """Sets the pod_count_history of this OrmModelServiceRevisionEdges.


        :param pod_count_history: The pod_count_history of this OrmModelServiceRevisionEdges.  # noqa: E501
        :type pod_count_history: list[OrmModelServicePodCountHistory]
        """

        self._pod_count_history = pod_count_history

    @property
    def workload(self):
        """Gets the workload of this OrmModelServiceRevisionEdges.  # noqa: E501


        :return: The workload of this OrmModelServiceRevisionEdges.  # noqa: E501
        :rtype: OrmWorkload
        """
        return self._workload

    @workload.setter
    def workload(self, workload):
        """Sets the workload of this OrmModelServiceRevisionEdges.


        :param workload: The workload of this OrmModelServiceRevisionEdges.  # noqa: E501
        :type workload: OrmWorkload
        """

        self._workload = workload

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmModelServiceRevisionEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmModelServiceRevisionEdges):
            return True

        return self.to_dict() != other.to_dict()



import os
from pathlib import Path
from typing import Type, Optional

import toml
from pydantic import BaseModel, ConfigDict

from vessl.util.constant import TRACING_AGREEMENT

DEFAULT_VESSL_DIR = os.path.join(str(Path.home()), ".vessl")
DEFAULT_CONFIG_PATH = os.environ.get("VESSL_CONFIG_PATH", os.path.join(DEFAULT_VESSL_DIR, "config"))
SAVE_CONFIG = os.environ.get("VESSL_SAVE_CONFIG", "true").lower() == "true"


class ConfigLoader:
    def __init__(self, filename: str, schema: Type[BaseModel]):
        self.filename = filename
        self.config = schema.model_validate(self._load())

    def _load(self):
        if not Path(self.filename).is_file():
            return {}

        with open(self.filename) as f:
            return toml.load(f)

    def reset(self):
        self.config = self.config.model_validate({})
        self.save()

    def save(self):
        if not SAVE_CONFIG:
            return
        os.makedirs(os.path.dirname(self.filename), exist_ok=True)
        with open(self.filename, "w") as f:
            toml.dump(self.config.model_dump(), f)


class UserConfig(BaseModel):
    access_token: Optional[str] = None
    default_organization: Optional[str] = None
    default_project: Optional[str] = None
    workspace: Optional[int] = None
    cluster_kubeconfig: Optional[str] = None
    kubernetes_namespace: Optional[str] = None
    use_k0s_in_docker: Optional[bool] = None
    default_ssh_private_key_path: Optional[str] = None

    model_config = ConfigDict(extra='ignore')


class VesslConfig(BaseModel):
    user: Optional[UserConfig] = UserConfig()


class VesslConfigLoader(ConfigLoader):
    config: VesslConfig

    def __init__(self, path: str = DEFAULT_CONFIG_PATH):
        super().__init__(path, VesslConfig)

    @property
    def access_token(self):
        return self.config.user.access_token

    @access_token.setter
    def access_token(self, access_token: str):
        if access_token:
            self.config.user.access_token = access_token
        self.save()

    @property
    def default_organization(self):
        return self.config.user.default_organization

    @default_organization.setter
    def default_organization(self, default_organization_name: str):
        self.config.user.default_organization = default_organization_name
        self.save()

    @property
    def default_project(self):
        return self.config.user.default_project

    @default_project.setter
    def default_project(self, default_project_name: str):
        self.config.user.default_project = default_project_name
        self.save()

    @property
    def workspace(self):
        return self.config.user.workspace

    @workspace.setter
    def workspace(self, workspace_id):
        self.config.user.workspace = workspace_id
        self.save()

    @property
    def cluster_kubeconfig(self) -> str:
        return self.config.user.cluster_kubeconfig

    @cluster_kubeconfig.setter
    def cluster_kubeconfig(self, cluster_kubeconfig_path: str):
        self.config.user.cluster_kubeconfig = cluster_kubeconfig_path
        self.save()

    @property
    def kubernetes_namespace(self) -> str:
        return self.config.user.kubernetes_namespace

    @kubernetes_namespace.setter
    def kubernetes_namespace(self, kubernetes_namespace: str):
        self.config.user.kubernetes_namespace = kubernetes_namespace
        self.save()

    @property
    def use_k0s_in_docker(self) -> bool:
        return self.config.user.use_k0s_in_docker

    @use_k0s_in_docker.setter
    def use_k0s_in_docker(self, use_k0s_in_docker: bool):
        self.config.user.use_k0s_in_docker = use_k0s_in_docker
        self.save()

    @property
    def default_ssh_private_key_path(self) -> str:
        return self.config.user.default_ssh_private_key_path

    @default_ssh_private_key_path.setter
    def default_ssh_private_key_path(self, default_ssh_private_key_path: str):
        self.config.user.default_ssh_private_key_path = default_ssh_private_key_path
        self.save()


def notified_user_data_collection() -> bool:
    file_path = os.path.join(DEFAULT_VESSL_DIR, "tracing-agreement")
    return Path(file_path).is_file()


def create_user_data_collection_file():
    path = os.path.join(DEFAULT_VESSL_DIR, "tracing-agreement")
    os.makedirs(DEFAULT_VESSL_DIR, exist_ok=True)
    with open(path, "w") as f:
        f.write(TRACING_AGREEMENT)




# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class V1SpecInspectionResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'errors': 'list[V1SpecError]',
        'is_spec_valid': 'bool',
        'warnings': 'list[V1SpecError]'
    }

    attribute_map = {
        'errors': 'errors',
        'is_spec_valid': 'is_spec_valid',
        'warnings': 'warnings'
    }

    def __init__(self, errors=None, is_spec_valid=None, warnings=None, local_vars_configuration=None):  # noqa: E501
        """V1SpecInspectionResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._errors = None
        self._is_spec_valid = None
        self._warnings = None
        self.discriminator = None

        if errors is not None:
            self.errors = errors
        if is_spec_valid is not None:
            self.is_spec_valid = is_spec_valid
        if warnings is not None:
            self.warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this V1SpecInspectionResult.  # noqa: E501


        :return: The errors of this V1SpecInspectionResult.  # noqa: E501
        :rtype: list[V1SpecError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this V1SpecInspectionResult.


        :param errors: The errors of this V1SpecInspectionResult.  # noqa: E501
        :type errors: list[V1SpecError]
        """

        self._errors = errors

    @property
    def is_spec_valid(self):
        """Gets the is_spec_valid of this V1SpecInspectionResult.  # noqa: E501


        :return: The is_spec_valid of this V1SpecInspectionResult.  # noqa: E501
        :rtype: bool
        """
        return self._is_spec_valid

    @is_spec_valid.setter
    def is_spec_valid(self, is_spec_valid):
        """Sets the is_spec_valid of this V1SpecInspectionResult.


        :param is_spec_valid: The is_spec_valid of this V1SpecInspectionResult.  # noqa: E501
        :type is_spec_valid: bool
        """

        self._is_spec_valid = is_spec_valid

    @property
    def warnings(self):
        """Gets the warnings of this V1SpecInspectionResult.  # noqa: E501


        :return: The warnings of this V1SpecInspectionResult.  # noqa: E501
        :rtype: list[V1SpecError]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this V1SpecInspectionResult.


        :param warnings: The warnings of this V1SpecInspectionResult.  # noqa: E501
        :type warnings: list[V1SpecError]
        """

        self._warnings = warnings

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1SpecInspectionResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1SpecInspectionResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class OrmOrganizationEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'artifacts': 'list[OrmArtifact]',
        'cluster_quotas': 'list[OrmClusterQuota]',
        'coupon_redemptions': 'list[OrmCouponRedemption]',
        'credit_earn_histories': 'list[OrmCreditEarnHistory]',
        'default_storage': 'OrmStorage',
        'default_volume': 'OrmVolume',
        'hub_model_tasks': 'list[OrmHubModelTask]',
        'hub_tags': 'list[OrmHubTag]',
        'kernel_clusters': 'list[OrmKernelCluster]',
        'llm_api_keys': 'list[OrmLLMApiKey]',
        'llm_documents': 'list[OrmLLMDocument]',
        'llm_knowledge': 'list[OrmLLMKnowledge]',
        'llm_model_connections': 'list[OrmLLMModelConnection]',
        'llm_user_groups': 'list[OrmLLMUserGroup]',
        'llm_vectordb_connections': 'list[OrmLLMVectorDBConnection]',
        'llm_workflows': 'list[OrmLLMWorkflow]',
        'model_services': 'list[OrmModelService]',
        'onboardings': 'list[OrmOnboarding]',
        'organization_credential_provider': 'list[OrmOrganizationCredentialProvider]',
        'organization_credentials': 'list[OrmOrganizationCredentials]',
        'organization_hub_model_tasks': 'list[OrmOrganizationHubModelTask]',
        'organization_kernel_clusters': 'list[OrmOrganizationKernelCluster]',
        'periodic_credit_events': 'list[OrmPeriodicCreditEvent]',
        'pipeline_step_types': 'list[OrmPipelineStepType]',
        'pipelines': 'list[OrmPipeline]',
        'price_overrides': 'list[OrmPriceOverride]',
        'pricing_plan': 'OrmPricingPlan',
        'primary_owner': 'OrmUser',
        'run_executions': 'list[OrmRunExecution]',
        'run_specs': 'list[OrmRunSpec]',
        'stripe_billing_history': 'list[OrmStripeBillingHistory]',
        'subscriptions': 'list[OrmOrganizationSubscription]',
        'unresolved_credits': 'list[OrmUnresolvedCredits]',
        'user_groups': 'list[OrmUserGroup]',
        'user_organization': 'list[OrmUserOrganization]',
        'users_with_this_as_default_organization': 'list[OrmUser]',
        'wallets': 'list[OrmWallet]',
        'withdraw_history_kernel_clusters': 'list[OrmWithdrawHistoryKernelCluster]',
        'withdraw_history_organizations': 'list[OrmWithdrawHistoryOrganization]',
        'workloads': 'list[OrmWorkload]',
        'workspaces': 'list[OrmWorkspace]'
    }

    attribute_map = {
        'artifacts': 'artifacts',
        'cluster_quotas': 'cluster_quotas',
        'coupon_redemptions': 'coupon_redemptions',
        'credit_earn_histories': 'credit_earn_histories',
        'default_storage': 'default_storage',
        'default_volume': 'default_volume',
        'hub_model_tasks': 'hub_model_tasks',
        'hub_tags': 'hub_tags',
        'kernel_clusters': 'kernel_clusters',
        'llm_api_keys': 'llm_api_keys',
        'llm_documents': 'llm_documents',
        'llm_knowledge': 'llm_knowledge',
        'llm_model_connections': 'llm_model_connections',
        'llm_user_groups': 'llm_user_groups',
        'llm_vectordb_connections': 'llm_vectordb_connections',
        'llm_workflows': 'llm_workflows',
        'model_services': 'model_services',
        'onboardings': 'onboardings',
        'organization_credential_provider': 'organization_credential_provider',
        'organization_credentials': 'organization_credentials',
        'organization_hub_model_tasks': 'organization_hub_model_tasks',
        'organization_kernel_clusters': 'organization_kernel_clusters',
        'periodic_credit_events': 'periodic_credit_events',
        'pipeline_step_types': 'pipeline_step_types',
        'pipelines': 'pipelines',
        'price_overrides': 'price_overrides',
        'pricing_plan': 'pricing_plan',
        'primary_owner': 'primary_owner',
        'run_executions': 'run_executions',
        'run_specs': 'run_specs',
        'stripe_billing_history': 'stripe_billing_history',
        'subscriptions': 'subscriptions',
        'unresolved_credits': 'unresolved_credits',
        'user_groups': 'user_groups',
        'user_organization': 'user_organization',
        'users_with_this_as_default_organization': 'users_with_this_as_default_organization',
        'wallets': 'wallets',
        'withdraw_history_kernel_clusters': 'withdraw_history_kernel_clusters',
        'withdraw_history_organizations': 'withdraw_history_organizations',
        'workloads': 'workloads',
        'workspaces': 'workspaces'
    }

    def __init__(self, artifacts=None, cluster_quotas=None, coupon_redemptions=None, credit_earn_histories=None, default_storage=None, default_volume=None, hub_model_tasks=None, hub_tags=None, kernel_clusters=None, llm_api_keys=None, llm_documents=None, llm_knowledge=None, llm_model_connections=None, llm_user_groups=None, llm_vectordb_connections=None, llm_workflows=None, model_services=None, onboardings=None, organization_credential_provider=None, organization_credentials=None, organization_hub_model_tasks=None, organization_kernel_clusters=None, periodic_credit_events=None, pipeline_step_types=None, pipelines=None, price_overrides=None, pricing_plan=None, primary_owner=None, run_executions=None, run_specs=None, stripe_billing_history=None, subscriptions=None, unresolved_credits=None, user_groups=None, user_organization=None, users_with_this_as_default_organization=None, wallets=None, withdraw_history_kernel_clusters=None, withdraw_history_organizations=None, workloads=None, workspaces=None, local_vars_configuration=None):  # noqa: E501
        """OrmOrganizationEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._artifacts = None
        self._cluster_quotas = None
        self._coupon_redemptions = None
        self._credit_earn_histories = None
        self._default_storage = None
        self._default_volume = None
        self._hub_model_tasks = None
        self._hub_tags = None
        self._kernel_clusters = None
        self._llm_api_keys = None
        self._llm_documents = None
        self._llm_knowledge = None
        self._llm_model_connections = None
        self._llm_user_groups = None
        self._llm_vectordb_connections = None
        self._llm_workflows = None
        self._model_services = None
        self._onboardings = None
        self._organization_credential_provider = None
        self._organization_credentials = None
        self._organization_hub_model_tasks = None
        self._organization_kernel_clusters = None
        self._periodic_credit_events = None
        self._pipeline_step_types = None
        self._pipelines = None
        self._price_overrides = None
        self._pricing_plan = None
        self._primary_owner = None
        self._run_executions = None
        self._run_specs = None
        self._stripe_billing_history = None
        self._subscriptions = None
        self._unresolved_credits = None
        self._user_groups = None
        self._user_organization = None
        self._users_with_this_as_default_organization = None
        self._wallets = None
        self._withdraw_history_kernel_clusters = None
        self._withdraw_history_organizations = None
        self._workloads = None
        self._workspaces = None
        self.discriminator = None

        if artifacts is not None:
            self.artifacts = artifacts
        if cluster_quotas is not None:
            self.cluster_quotas = cluster_quotas
        if coupon_redemptions is not None:
            self.coupon_redemptions = coupon_redemptions
        if credit_earn_histories is not None:
            self.credit_earn_histories = credit_earn_histories
        if default_storage is not None:
            self.default_storage = default_storage
        if default_volume is not None:
            self.default_volume = default_volume
        if hub_model_tasks is not None:
            self.hub_model_tasks = hub_model_tasks
        if hub_tags is not None:
            self.hub_tags = hub_tags
        if kernel_clusters is not None:
            self.kernel_clusters = kernel_clusters
        if llm_api_keys is not None:
            self.llm_api_keys = llm_api_keys
        if llm_documents is not None:
            self.llm_documents = llm_documents
        if llm_knowledge is not None:
            self.llm_knowledge = llm_knowledge
        if llm_model_connections is not None:
            self.llm_model_connections = llm_model_connections
        if llm_user_groups is not None:
            self.llm_user_groups = llm_user_groups
        if llm_vectordb_connections is not None:
            self.llm_vectordb_connections = llm_vectordb_connections
        if llm_workflows is not None:
            self.llm_workflows = llm_workflows
        if model_services is not None:
            self.model_services = model_services
        if onboardings is not None:
            self.onboardings = onboardings
        if organization_credential_provider is not None:
            self.organization_credential_provider = organization_credential_provider
        if organization_credentials is not None:
            self.organization_credentials = organization_credentials
        if organization_hub_model_tasks is not None:
            self.organization_hub_model_tasks = organization_hub_model_tasks
        if organization_kernel_clusters is not None:
            self.organization_kernel_clusters = organization_kernel_clusters
        if periodic_credit_events is not None:
            self.periodic_credit_events = periodic_credit_events
        if pipeline_step_types is not None:
            self.pipeline_step_types = pipeline_step_types
        if pipelines is not None:
            self.pipelines = pipelines
        if price_overrides is not None:
            self.price_overrides = price_overrides
        if pricing_plan is not None:
            self.pricing_plan = pricing_plan
        if primary_owner is not None:
            self.primary_owner = primary_owner
        if run_executions is not None:
            self.run_executions = run_executions
        if run_specs is not None:
            self.run_specs = run_specs
        if stripe_billing_history is not None:
            self.stripe_billing_history = stripe_billing_history
        if subscriptions is not None:
            self.subscriptions = subscriptions
        if unresolved_credits is not None:
            self.unresolved_credits = unresolved_credits
        if user_groups is not None:
            self.user_groups = user_groups
        if user_organization is not None:
            self.user_organization = user_organization
        if users_with_this_as_default_organization is not None:
            self.users_with_this_as_default_organization = users_with_this_as_default_organization
        if wallets is not None:
            self.wallets = wallets
        if withdraw_history_kernel_clusters is not None:
            self.withdraw_history_kernel_clusters = withdraw_history_kernel_clusters
        if withdraw_history_organizations is not None:
            self.withdraw_history_organizations = withdraw_history_organizations
        if workloads is not None:
            self.workloads = workloads
        if workspaces is not None:
            self.workspaces = workspaces

    @property
    def artifacts(self):
        """Gets the artifacts of this OrmOrganizationEdges.  # noqa: E501


        :return: The artifacts of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmArtifact]
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this OrmOrganizationEdges.


        :param artifacts: The artifacts of this OrmOrganizationEdges.  # noqa: E501
        :type artifacts: list[OrmArtifact]
        """

        self._artifacts = artifacts

    @property
    def cluster_quotas(self):
        """Gets the cluster_quotas of this OrmOrganizationEdges.  # noqa: E501


        :return: The cluster_quotas of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmClusterQuota]
        """
        return self._cluster_quotas

    @cluster_quotas.setter
    def cluster_quotas(self, cluster_quotas):
        """Sets the cluster_quotas of this OrmOrganizationEdges.


        :param cluster_quotas: The cluster_quotas of this OrmOrganizationEdges.  # noqa: E501
        :type cluster_quotas: list[OrmClusterQuota]
        """

        self._cluster_quotas = cluster_quotas

    @property
    def coupon_redemptions(self):
        """Gets the coupon_redemptions of this OrmOrganizationEdges.  # noqa: E501


        :return: The coupon_redemptions of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmCouponRedemption]
        """
        return self._coupon_redemptions

    @coupon_redemptions.setter
    def coupon_redemptions(self, coupon_redemptions):
        """Sets the coupon_redemptions of this OrmOrganizationEdges.


        :param coupon_redemptions: The coupon_redemptions of this OrmOrganizationEdges.  # noqa: E501
        :type coupon_redemptions: list[OrmCouponRedemption]
        """

        self._coupon_redemptions = coupon_redemptions

    @property
    def credit_earn_histories(self):
        """Gets the credit_earn_histories of this OrmOrganizationEdges.  # noqa: E501


        :return: The credit_earn_histories of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmCreditEarnHistory]
        """
        return self._credit_earn_histories

    @credit_earn_histories.setter
    def credit_earn_histories(self, credit_earn_histories):
        """Sets the credit_earn_histories of this OrmOrganizationEdges.


        :param credit_earn_histories: The credit_earn_histories of this OrmOrganizationEdges.  # noqa: E501
        :type credit_earn_histories: list[OrmCreditEarnHistory]
        """

        self._credit_earn_histories = credit_earn_histories

    @property
    def default_storage(self):
        """Gets the default_storage of this OrmOrganizationEdges.  # noqa: E501


        :return: The default_storage of this OrmOrganizationEdges.  # noqa: E501
        :rtype: OrmStorage
        """
        return self._default_storage

    @default_storage.setter
    def default_storage(self, default_storage):
        """Sets the default_storage of this OrmOrganizationEdges.


        :param default_storage: The default_storage of this OrmOrganizationEdges.  # noqa: E501
        :type default_storage: OrmStorage
        """

        self._default_storage = default_storage

    @property
    def default_volume(self):
        """Gets the default_volume of this OrmOrganizationEdges.  # noqa: E501


        :return: The default_volume of this OrmOrganizationEdges.  # noqa: E501
        :rtype: OrmVolume
        """
        return self._default_volume

    @default_volume.setter
    def default_volume(self, default_volume):
        """Sets the default_volume of this OrmOrganizationEdges.


        :param default_volume: The default_volume of this OrmOrganizationEdges.  # noqa: E501
        :type default_volume: OrmVolume
        """

        self._default_volume = default_volume

    @property
    def hub_model_tasks(self):
        """Gets the hub_model_tasks of this OrmOrganizationEdges.  # noqa: E501


        :return: The hub_model_tasks of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmHubModelTask]
        """
        return self._hub_model_tasks

    @hub_model_tasks.setter
    def hub_model_tasks(self, hub_model_tasks):
        """Sets the hub_model_tasks of this OrmOrganizationEdges.


        :param hub_model_tasks: The hub_model_tasks of this OrmOrganizationEdges.  # noqa: E501
        :type hub_model_tasks: list[OrmHubModelTask]
        """

        self._hub_model_tasks = hub_model_tasks

    @property
    def hub_tags(self):
        """Gets the hub_tags of this OrmOrganizationEdges.  # noqa: E501


        :return: The hub_tags of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmHubTag]
        """
        return self._hub_tags

    @hub_tags.setter
    def hub_tags(self, hub_tags):
        """Sets the hub_tags of this OrmOrganizationEdges.


        :param hub_tags: The hub_tags of this OrmOrganizationEdges.  # noqa: E501
        :type hub_tags: list[OrmHubTag]
        """

        self._hub_tags = hub_tags

    @property
    def kernel_clusters(self):
        """Gets the kernel_clusters of this OrmOrganizationEdges.  # noqa: E501


        :return: The kernel_clusters of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmKernelCluster]
        """
        return self._kernel_clusters

    @kernel_clusters.setter
    def kernel_clusters(self, kernel_clusters):
        """Sets the kernel_clusters of this OrmOrganizationEdges.


        :param kernel_clusters: The kernel_clusters of this OrmOrganizationEdges.  # noqa: E501
        :type kernel_clusters: list[OrmKernelCluster]
        """

        self._kernel_clusters = kernel_clusters

    @property
    def llm_api_keys(self):
        """Gets the llm_api_keys of this OrmOrganizationEdges.  # noqa: E501


        :return: The llm_api_keys of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmLLMApiKey]
        """
        return self._llm_api_keys

    @llm_api_keys.setter
    def llm_api_keys(self, llm_api_keys):
        """Sets the llm_api_keys of this OrmOrganizationEdges.


        :param llm_api_keys: The llm_api_keys of this OrmOrganizationEdges.  # noqa: E501
        :type llm_api_keys: list[OrmLLMApiKey]
        """

        self._llm_api_keys = llm_api_keys

    @property
    def llm_documents(self):
        """Gets the llm_documents of this OrmOrganizationEdges.  # noqa: E501


        :return: The llm_documents of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmLLMDocument]
        """
        return self._llm_documents

    @llm_documents.setter
    def llm_documents(self, llm_documents):
        """Sets the llm_documents of this OrmOrganizationEdges.


        :param llm_documents: The llm_documents of this OrmOrganizationEdges.  # noqa: E501
        :type llm_documents: list[OrmLLMDocument]
        """

        self._llm_documents = llm_documents

    @property
    def llm_knowledge(self):
        """Gets the llm_knowledge of this OrmOrganizationEdges.  # noqa: E501


        :return: The llm_knowledge of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmLLMKnowledge]
        """
        return self._llm_knowledge

    @llm_knowledge.setter
    def llm_knowledge(self, llm_knowledge):
        """Sets the llm_knowledge of this OrmOrganizationEdges.


        :param llm_knowledge: The llm_knowledge of this OrmOrganizationEdges.  # noqa: E501
        :type llm_knowledge: list[OrmLLMKnowledge]
        """

        self._llm_knowledge = llm_knowledge

    @property
    def llm_model_connections(self):
        """Gets the llm_model_connections of this OrmOrganizationEdges.  # noqa: E501


        :return: The llm_model_connections of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmLLMModelConnection]
        """
        return self._llm_model_connections

    @llm_model_connections.setter
    def llm_model_connections(self, llm_model_connections):
        """Sets the llm_model_connections of this OrmOrganizationEdges.


        :param llm_model_connections: The llm_model_connections of this OrmOrganizationEdges.  # noqa: E501
        :type llm_model_connections: list[OrmLLMModelConnection]
        """

        self._llm_model_connections = llm_model_connections

    @property
    def llm_user_groups(self):
        """Gets the llm_user_groups of this OrmOrganizationEdges.  # noqa: E501


        :return: The llm_user_groups of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmLLMUserGroup]
        """
        return self._llm_user_groups

    @llm_user_groups.setter
    def llm_user_groups(self, llm_user_groups):
        """Sets the llm_user_groups of this OrmOrganizationEdges.


        :param llm_user_groups: The llm_user_groups of this OrmOrganizationEdges.  # noqa: E501
        :type llm_user_groups: list[OrmLLMUserGroup]
        """

        self._llm_user_groups = llm_user_groups

    @property
    def llm_vectordb_connections(self):
        """Gets the llm_vectordb_connections of this OrmOrganizationEdges.  # noqa: E501


        :return: The llm_vectordb_connections of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmLLMVectorDBConnection]
        """
        return self._llm_vectordb_connections

    @llm_vectordb_connections.setter
    def llm_vectordb_connections(self, llm_vectordb_connections):
        """Sets the llm_vectordb_connections of this OrmOrganizationEdges.


        :param llm_vectordb_connections: The llm_vectordb_connections of this OrmOrganizationEdges.  # noqa: E501
        :type llm_vectordb_connections: list[OrmLLMVectorDBConnection]
        """

        self._llm_vectordb_connections = llm_vectordb_connections

    @property
    def llm_workflows(self):
        """Gets the llm_workflows of this OrmOrganizationEdges.  # noqa: E501


        :return: The llm_workflows of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmLLMWorkflow]
        """
        return self._llm_workflows

    @llm_workflows.setter
    def llm_workflows(self, llm_workflows):
        """Sets the llm_workflows of this OrmOrganizationEdges.


        :param llm_workflows: The llm_workflows of this OrmOrganizationEdges.  # noqa: E501
        :type llm_workflows: list[OrmLLMWorkflow]
        """

        self._llm_workflows = llm_workflows

    @property
    def model_services(self):
        """Gets the model_services of this OrmOrganizationEdges.  # noqa: E501


        :return: The model_services of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmModelService]
        """
        return self._model_services

    @model_services.setter
    def model_services(self, model_services):
        """Sets the model_services of this OrmOrganizationEdges.


        :param model_services: The model_services of this OrmOrganizationEdges.  # noqa: E501
        :type model_services: list[OrmModelService]
        """

        self._model_services = model_services

    @property
    def onboardings(self):
        """Gets the onboardings of this OrmOrganizationEdges.  # noqa: E501


        :return: The onboardings of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmOnboarding]
        """
        return self._onboardings

    @onboardings.setter
    def onboardings(self, onboardings):
        """Sets the onboardings of this OrmOrganizationEdges.


        :param onboardings: The onboardings of this OrmOrganizationEdges.  # noqa: E501
        :type onboardings: list[OrmOnboarding]
        """

        self._onboardings = onboardings

    @property
    def organization_credential_provider(self):
        """Gets the organization_credential_provider of this OrmOrganizationEdges.  # noqa: E501


        :return: The organization_credential_provider of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmOrganizationCredentialProvider]
        """
        return self._organization_credential_provider

    @organization_credential_provider.setter
    def organization_credential_provider(self, organization_credential_provider):
        """Sets the organization_credential_provider of this OrmOrganizationEdges.


        :param organization_credential_provider: The organization_credential_provider of this OrmOrganizationEdges.  # noqa: E501
        :type organization_credential_provider: list[OrmOrganizationCredentialProvider]
        """

        self._organization_credential_provider = organization_credential_provider

    @property
    def organization_credentials(self):
        """Gets the organization_credentials of this OrmOrganizationEdges.  # noqa: E501


        :return: The organization_credentials of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmOrganizationCredentials]
        """
        return self._organization_credentials

    @organization_credentials.setter
    def organization_credentials(self, organization_credentials):
        """Sets the organization_credentials of this OrmOrganizationEdges.


        :param organization_credentials: The organization_credentials of this OrmOrganizationEdges.  # noqa: E501
        :type organization_credentials: list[OrmOrganizationCredentials]
        """

        self._organization_credentials = organization_credentials

    @property
    def organization_hub_model_tasks(self):
        """Gets the organization_hub_model_tasks of this OrmOrganizationEdges.  # noqa: E501


        :return: The organization_hub_model_tasks of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmOrganizationHubModelTask]
        """
        return self._organization_hub_model_tasks

    @organization_hub_model_tasks.setter
    def organization_hub_model_tasks(self, organization_hub_model_tasks):
        """Sets the organization_hub_model_tasks of this OrmOrganizationEdges.


        :param organization_hub_model_tasks: The organization_hub_model_tasks of this OrmOrganizationEdges.  # noqa: E501
        :type organization_hub_model_tasks: list[OrmOrganizationHubModelTask]
        """

        self._organization_hub_model_tasks = organization_hub_model_tasks

    @property
    def organization_kernel_clusters(self):
        """Gets the organization_kernel_clusters of this OrmOrganizationEdges.  # noqa: E501


        :return: The organization_kernel_clusters of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmOrganizationKernelCluster]
        """
        return self._organization_kernel_clusters

    @organization_kernel_clusters.setter
    def organization_kernel_clusters(self, organization_kernel_clusters):
        """Sets the organization_kernel_clusters of this OrmOrganizationEdges.


        :param organization_kernel_clusters: The organization_kernel_clusters of this OrmOrganizationEdges.  # noqa: E501
        :type organization_kernel_clusters: list[OrmOrganizationKernelCluster]
        """

        self._organization_kernel_clusters = organization_kernel_clusters

    @property
    def periodic_credit_events(self):
        """Gets the periodic_credit_events of this OrmOrganizationEdges.  # noqa: E501


        :return: The periodic_credit_events of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmPeriodicCreditEvent]
        """
        return self._periodic_credit_events

    @periodic_credit_events.setter
    def periodic_credit_events(self, periodic_credit_events):
        """Sets the periodic_credit_events of this OrmOrganizationEdges.


        :param periodic_credit_events: The periodic_credit_events of this OrmOrganizationEdges.  # noqa: E501
        :type periodic_credit_events: list[OrmPeriodicCreditEvent]
        """

        self._periodic_credit_events = periodic_credit_events

    @property
    def pipeline_step_types(self):
        """Gets the pipeline_step_types of this OrmOrganizationEdges.  # noqa: E501


        :return: The pipeline_step_types of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmPipelineStepType]
        """
        return self._pipeline_step_types

    @pipeline_step_types.setter
    def pipeline_step_types(self, pipeline_step_types):
        """Sets the pipeline_step_types of this OrmOrganizationEdges.


        :param pipeline_step_types: The pipeline_step_types of this OrmOrganizationEdges.  # noqa: E501
        :type pipeline_step_types: list[OrmPipelineStepType]
        """

        self._pipeline_step_types = pipeline_step_types

    @property
    def pipelines(self):
        """Gets the pipelines of this OrmOrganizationEdges.  # noqa: E501


        :return: The pipelines of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmPipeline]
        """
        return self._pipelines

    @pipelines.setter
    def pipelines(self, pipelines):
        """Sets the pipelines of this OrmOrganizationEdges.


        :param pipelines: The pipelines of this OrmOrganizationEdges.  # noqa: E501
        :type pipelines: list[OrmPipeline]
        """

        self._pipelines = pipelines

    @property
    def price_overrides(self):
        """Gets the price_overrides of this OrmOrganizationEdges.  # noqa: E501


        :return: The price_overrides of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmPriceOverride]
        """
        return self._price_overrides

    @price_overrides.setter
    def price_overrides(self, price_overrides):
        """Sets the price_overrides of this OrmOrganizationEdges.


        :param price_overrides: The price_overrides of this OrmOrganizationEdges.  # noqa: E501
        :type price_overrides: list[OrmPriceOverride]
        """

        self._price_overrides = price_overrides

    @property
    def pricing_plan(self):
        """Gets the pricing_plan of this OrmOrganizationEdges.  # noqa: E501


        :return: The pricing_plan of this OrmOrganizationEdges.  # noqa: E501
        :rtype: OrmPricingPlan
        """
        return self._pricing_plan

    @pricing_plan.setter
    def pricing_plan(self, pricing_plan):
        """Sets the pricing_plan of this OrmOrganizationEdges.


        :param pricing_plan: The pricing_plan of this OrmOrganizationEdges.  # noqa: E501
        :type pricing_plan: OrmPricingPlan
        """

        self._pricing_plan = pricing_plan

    @property
    def primary_owner(self):
        """Gets the primary_owner of this OrmOrganizationEdges.  # noqa: E501


        :return: The primary_owner of this OrmOrganizationEdges.  # noqa: E501
        :rtype: OrmUser
        """
        return self._primary_owner

    @primary_owner.setter
    def primary_owner(self, primary_owner):
        """Sets the primary_owner of this OrmOrganizationEdges.


        :param primary_owner: The primary_owner of this OrmOrganizationEdges.  # noqa: E501
        :type primary_owner: OrmUser
        """

        self._primary_owner = primary_owner

    @property
    def run_executions(self):
        """Gets the run_executions of this OrmOrganizationEdges.  # noqa: E501


        :return: The run_executions of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmRunExecution]
        """
        return self._run_executions

    @run_executions.setter
    def run_executions(self, run_executions):
        """Sets the run_executions of this OrmOrganizationEdges.


        :param run_executions: The run_executions of this OrmOrganizationEdges.  # noqa: E501
        :type run_executions: list[OrmRunExecution]
        """

        self._run_executions = run_executions

    @property
    def run_specs(self):
        """Gets the run_specs of this OrmOrganizationEdges.  # noqa: E501


        :return: The run_specs of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmRunSpec]
        """
        return self._run_specs

    @run_specs.setter
    def run_specs(self, run_specs):
        """Sets the run_specs of this OrmOrganizationEdges.


        :param run_specs: The run_specs of this OrmOrganizationEdges.  # noqa: E501
        :type run_specs: list[OrmRunSpec]
        """

        self._run_specs = run_specs

    @property
    def stripe_billing_history(self):
        """Gets the stripe_billing_history of this OrmOrganizationEdges.  # noqa: E501


        :return: The stripe_billing_history of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmStripeBillingHistory]
        """
        return self._stripe_billing_history

    @stripe_billing_history.setter
    def stripe_billing_history(self, stripe_billing_history):
        """Sets the stripe_billing_history of this OrmOrganizationEdges.


        :param stripe_billing_history: The stripe_billing_history of this OrmOrganizationEdges.  # noqa: E501
        :type stripe_billing_history: list[OrmStripeBillingHistory]
        """

        self._stripe_billing_history = stripe_billing_history

    @property
    def subscriptions(self):
        """Gets the subscriptions of this OrmOrganizationEdges.  # noqa: E501


        :return: The subscriptions of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmOrganizationSubscription]
        """
        return self._subscriptions

    @subscriptions.setter
    def subscriptions(self, subscriptions):
        """Sets the subscriptions of this OrmOrganizationEdges.


        :param subscriptions: The subscriptions of this OrmOrganizationEdges.  # noqa: E501
        :type subscriptions: list[OrmOrganizationSubscription]
        """

        self._subscriptions = subscriptions

    @property
    def unresolved_credits(self):
        """Gets the unresolved_credits of this OrmOrganizationEdges.  # noqa: E501


        :return: The unresolved_credits of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmUnresolvedCredits]
        """
        return self._unresolved_credits

    @unresolved_credits.setter
    def unresolved_credits(self, unresolved_credits):
        """Sets the unresolved_credits of this OrmOrganizationEdges.


        :param unresolved_credits: The unresolved_credits of this OrmOrganizationEdges.  # noqa: E501
        :type unresolved_credits: list[OrmUnresolvedCredits]
        """

        self._unresolved_credits = unresolved_credits

    @property
    def user_groups(self):
        """Gets the user_groups of this OrmOrganizationEdges.  # noqa: E501


        :return: The user_groups of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmUserGroup]
        """
        return self._user_groups

    @user_groups.setter
    def user_groups(self, user_groups):
        """Sets the user_groups of this OrmOrganizationEdges.


        :param user_groups: The user_groups of this OrmOrganizationEdges.  # noqa: E501
        :type user_groups: list[OrmUserGroup]
        """

        self._user_groups = user_groups

    @property
    def user_organization(self):
        """Gets the user_organization of this OrmOrganizationEdges.  # noqa: E501


        :return: The user_organization of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmUserOrganization]
        """
        return self._user_organization

    @user_organization.setter
    def user_organization(self, user_organization):
        """Sets the user_organization of this OrmOrganizationEdges.


        :param user_organization: The user_organization of this OrmOrganizationEdges.  # noqa: E501
        :type user_organization: list[OrmUserOrganization]
        """

        self._user_organization = user_organization

    @property
    def users_with_this_as_default_organization(self):
        """Gets the users_with_this_as_default_organization of this OrmOrganizationEdges.  # noqa: E501


        :return: The users_with_this_as_default_organization of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmUser]
        """
        return self._users_with_this_as_default_organization

    @users_with_this_as_default_organization.setter
    def users_with_this_as_default_organization(self, users_with_this_as_default_organization):
        """Sets the users_with_this_as_default_organization of this OrmOrganizationEdges.


        :param users_with_this_as_default_organization: The users_with_this_as_default_organization of this OrmOrganizationEdges.  # noqa: E501
        :type users_with_this_as_default_organization: list[OrmUser]
        """

        self._users_with_this_as_default_organization = users_with_this_as_default_organization

    @property
    def wallets(self):
        """Gets the wallets of this OrmOrganizationEdges.  # noqa: E501


        :return: The wallets of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmWallet]
        """
        return self._wallets

    @wallets.setter
    def wallets(self, wallets):
        """Sets the wallets of this OrmOrganizationEdges.


        :param wallets: The wallets of this OrmOrganizationEdges.  # noqa: E501
        :type wallets: list[OrmWallet]
        """

        self._wallets = wallets

    @property
    def withdraw_history_kernel_clusters(self):
        """Gets the withdraw_history_kernel_clusters of this OrmOrganizationEdges.  # noqa: E501


        :return: The withdraw_history_kernel_clusters of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmWithdrawHistoryKernelCluster]
        """
        return self._withdraw_history_kernel_clusters

    @withdraw_history_kernel_clusters.setter
    def withdraw_history_kernel_clusters(self, withdraw_history_kernel_clusters):
        """Sets the withdraw_history_kernel_clusters of this OrmOrganizationEdges.


        :param withdraw_history_kernel_clusters: The withdraw_history_kernel_clusters of this OrmOrganizationEdges.  # noqa: E501
        :type withdraw_history_kernel_clusters: list[OrmWithdrawHistoryKernelCluster]
        """

        self._withdraw_history_kernel_clusters = withdraw_history_kernel_clusters

    @property
    def withdraw_history_organizations(self):
        """Gets the withdraw_history_organizations of this OrmOrganizationEdges.  # noqa: E501


        :return: The withdraw_history_organizations of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmWithdrawHistoryOrganization]
        """
        return self._withdraw_history_organizations

    @withdraw_history_organizations.setter
    def withdraw_history_organizations(self, withdraw_history_organizations):
        """Sets the withdraw_history_organizations of this OrmOrganizationEdges.


        :param withdraw_history_organizations: The withdraw_history_organizations of this OrmOrganizationEdges.  # noqa: E501
        :type withdraw_history_organizations: list[OrmWithdrawHistoryOrganization]
        """

        self._withdraw_history_organizations = withdraw_history_organizations

    @property
    def workloads(self):
        """Gets the workloads of this OrmOrganizationEdges.  # noqa: E501


        :return: The workloads of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmWorkload]
        """
        return self._workloads

    @workloads.setter
    def workloads(self, workloads):
        """Sets the workloads of this OrmOrganizationEdges.


        :param workloads: The workloads of this OrmOrganizationEdges.  # noqa: E501
        :type workloads: list[OrmWorkload]
        """

        self._workloads = workloads

    @property
    def workspaces(self):
        """Gets the workspaces of this OrmOrganizationEdges.  # noqa: E501


        :return: The workspaces of this OrmOrganizationEdges.  # noqa: E501
        :rtype: list[OrmWorkspace]
        """
        return self._workspaces

    @workspaces.setter
    def workspaces(self, workspaces):
        """Sets the workspaces of this OrmOrganizationEdges.


        :param workspaces: The workspaces of this OrmOrganizationEdges.  # noqa: E501
        :type workspaces: list[OrmWorkspace]
        """

        self._workspaces = workspaces

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmOrganizationEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmOrganizationEdges):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from vessl.openapi_client.configuration import Configuration


class OrganizationOrganizationBillingConfigReadResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'auto_topup_amount': 'float',
        'auto_topup_enabled': 'bool',
        'auto_topup_threshold': 'float',
        'cancel_at_period_end': 'bool',
        'card_brand': 'str',
        'card_expiry': 'str',
        'card_last_digits': 'str',
        'card_registered': 'bool',
        'credit_balance': 'float',
        'current_plan': 'str',
        'next_renewal_date': 'str',
        'show_add_payment_method_button': 'bool',
        'show_renewal_date': 'bool'
    }

    attribute_map = {
        'auto_topup_amount': 'auto_topup_amount',
        'auto_topup_enabled': 'auto_topup_enabled',
        'auto_topup_threshold': 'auto_topup_threshold',
        'cancel_at_period_end': 'cancel_at_period_end',
        'card_brand': 'card_brand',
        'card_expiry': 'card_expiry',
        'card_last_digits': 'card_last_digits',
        'card_registered': 'card_registered',
        'credit_balance': 'credit_balance',
        'current_plan': 'current_plan',
        'next_renewal_date': 'next_renewal_date',
        'show_add_payment_method_button': 'show_add_payment_method_button',
        'show_renewal_date': 'show_renewal_date'
    }

    def __init__(self, auto_topup_amount=None, auto_topup_enabled=None, auto_topup_threshold=None, cancel_at_period_end=None, card_brand=None, card_expiry=None, card_last_digits=None, card_registered=None, credit_balance=None, current_plan=None, next_renewal_date=None, show_add_payment_method_button=None, show_renewal_date=None, local_vars_configuration=None):  # noqa: E501
        """OrganizationOrganizationBillingConfigReadResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._auto_topup_amount = None
        self._auto_topup_enabled = None
        self._auto_topup_threshold = None
        self._cancel_at_period_end = None
        self._card_brand = None
        self._card_expiry = None
        self._card_last_digits = None
        self._card_registered = None
        self._credit_balance = None
        self._current_plan = None
        self._next_renewal_date = None
        self._show_add_payment_method_button = None
        self._show_renewal_date = None
        self.discriminator = None

        if auto_topup_amount is not None:
            self.auto_topup_amount = auto_topup_amount
        self.auto_topup_enabled = auto_topup_enabled
        if auto_topup_threshold is not None:
            self.auto_topup_threshold = auto_topup_threshold
        self.cancel_at_period_end = cancel_at_period_end
        if card_brand is not None:
            self.card_brand = card_brand
        if card_expiry is not None:
            self.card_expiry = card_expiry
        if card_last_digits is not None:
            self.card_last_digits = card_last_digits
        self.card_registered = card_registered
        self.credit_balance = credit_balance
        self.current_plan = current_plan
        if next_renewal_date is not None:
            self.next_renewal_date = next_renewal_date
        self.show_add_payment_method_button = show_add_payment_method_button
        self.show_renewal_date = show_renewal_date

    @property
    def auto_topup_amount(self):
        """Gets the auto_topup_amount of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The auto_topup_amount of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: float
        """
        return self._auto_topup_amount

    @auto_topup_amount.setter
    def auto_topup_amount(self, auto_topup_amount):
        """Sets the auto_topup_amount of this OrganizationOrganizationBillingConfigReadResponse.


        :param auto_topup_amount: The auto_topup_amount of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type auto_topup_amount: float
        """

        self._auto_topup_amount = auto_topup_amount

    @property
    def auto_topup_enabled(self):
        """Gets the auto_topup_enabled of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The auto_topup_enabled of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: bool
        """
        return self._auto_topup_enabled

    @auto_topup_enabled.setter
    def auto_topup_enabled(self, auto_topup_enabled):
        """Sets the auto_topup_enabled of this OrganizationOrganizationBillingConfigReadResponse.


        :param auto_topup_enabled: The auto_topup_enabled of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type auto_topup_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and auto_topup_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `auto_topup_enabled`, must not be `None`")  # noqa: E501

        self._auto_topup_enabled = auto_topup_enabled

    @property
    def auto_topup_threshold(self):
        """Gets the auto_topup_threshold of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The auto_topup_threshold of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: float
        """
        return self._auto_topup_threshold

    @auto_topup_threshold.setter
    def auto_topup_threshold(self, auto_topup_threshold):
        """Sets the auto_topup_threshold of this OrganizationOrganizationBillingConfigReadResponse.


        :param auto_topup_threshold: The auto_topup_threshold of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type auto_topup_threshold: float
        """

        self._auto_topup_threshold = auto_topup_threshold

    @property
    def cancel_at_period_end(self):
        """Gets the cancel_at_period_end of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The cancel_at_period_end of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: bool
        """
        return self._cancel_at_period_end

    @cancel_at_period_end.setter
    def cancel_at_period_end(self, cancel_at_period_end):
        """Sets the cancel_at_period_end of this OrganizationOrganizationBillingConfigReadResponse.


        :param cancel_at_period_end: The cancel_at_period_end of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type cancel_at_period_end: bool
        """
        if self.local_vars_configuration.client_side_validation and cancel_at_period_end is None:  # noqa: E501
            raise ValueError("Invalid value for `cancel_at_period_end`, must not be `None`")  # noqa: E501

        self._cancel_at_period_end = cancel_at_period_end

    @property
    def card_brand(self):
        """Gets the card_brand of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The card_brand of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: str
        """
        return self._card_brand

    @card_brand.setter
    def card_brand(self, card_brand):
        """Sets the card_brand of this OrganizationOrganizationBillingConfigReadResponse.


        :param card_brand: The card_brand of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type card_brand: str
        """

        self._card_brand = card_brand

    @property
    def card_expiry(self):
        """Gets the card_expiry of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The card_expiry of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: str
        """
        return self._card_expiry

    @card_expiry.setter
    def card_expiry(self, card_expiry):
        """Sets the card_expiry of this OrganizationOrganizationBillingConfigReadResponse.


        :param card_expiry: The card_expiry of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type card_expiry: str
        """

        self._card_expiry = card_expiry

    @property
    def card_last_digits(self):
        """Gets the card_last_digits of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The card_last_digits of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: str
        """
        return self._card_last_digits

    @card_last_digits.setter
    def card_last_digits(self, card_last_digits):
        """Sets the card_last_digits of this OrganizationOrganizationBillingConfigReadResponse.


        :param card_last_digits: The card_last_digits of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type card_last_digits: str
        """

        self._card_last_digits = card_last_digits

    @property
    def card_registered(self):
        """Gets the card_registered of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The card_registered of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: bool
        """
        return self._card_registered

    @card_registered.setter
    def card_registered(self, card_registered):
        """Sets the card_registered of this OrganizationOrganizationBillingConfigReadResponse.


        :param card_registered: The card_registered of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type card_registered: bool
        """
        if self.local_vars_configuration.client_side_validation and card_registered is None:  # noqa: E501
            raise ValueError("Invalid value for `card_registered`, must not be `None`")  # noqa: E501

        self._card_registered = card_registered

    @property
    def credit_balance(self):
        """Gets the credit_balance of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The credit_balance of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: float
        """
        return self._credit_balance

    @credit_balance.setter
    def credit_balance(self, credit_balance):
        """Sets the credit_balance of this OrganizationOrganizationBillingConfigReadResponse.


        :param credit_balance: The credit_balance of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type credit_balance: float
        """
        if self.local_vars_configuration.client_side_validation and credit_balance is None:  # noqa: E501
            raise ValueError("Invalid value for `credit_balance`, must not be `None`")  # noqa: E501

        self._credit_balance = credit_balance

    @property
    def current_plan(self):
        """Gets the current_plan of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The current_plan of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: str
        """
        return self._current_plan

    @current_plan.setter
    def current_plan(self, current_plan):
        """Sets the current_plan of this OrganizationOrganizationBillingConfigReadResponse.


        :param current_plan: The current_plan of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type current_plan: str
        """
        if self.local_vars_configuration.client_side_validation and current_plan is None:  # noqa: E501
            raise ValueError("Invalid value for `current_plan`, must not be `None`")  # noqa: E501

        self._current_plan = current_plan

    @property
    def next_renewal_date(self):
        """Gets the next_renewal_date of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The next_renewal_date of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: str
        """
        return self._next_renewal_date

    @next_renewal_date.setter
    def next_renewal_date(self, next_renewal_date):
        """Sets the next_renewal_date of this OrganizationOrganizationBillingConfigReadResponse.


        :param next_renewal_date: The next_renewal_date of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type next_renewal_date: str
        """

        self._next_renewal_date = next_renewal_date

    @property
    def show_add_payment_method_button(self):
        """Gets the show_add_payment_method_button of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The show_add_payment_method_button of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: bool
        """
        return self._show_add_payment_method_button

    @show_add_payment_method_button.setter
    def show_add_payment_method_button(self, show_add_payment_method_button):
        """Sets the show_add_payment_method_button of this OrganizationOrganizationBillingConfigReadResponse.


        :param show_add_payment_method_button: The show_add_payment_method_button of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type show_add_payment_method_button: bool
        """
        if self.local_vars_configuration.client_side_validation and show_add_payment_method_button is None:  # noqa: E501
            raise ValueError("Invalid value for `show_add_payment_method_button`, must not be `None`")  # noqa: E501

        self._show_add_payment_method_button = show_add_payment_method_button

    @property
    def show_renewal_date(self):
        """Gets the show_renewal_date of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501


        :return: The show_renewal_date of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :rtype: bool
        """
        return self._show_renewal_date

    @show_renewal_date.setter
    def show_renewal_date(self, show_renewal_date):
        """Sets the show_renewal_date of this OrganizationOrganizationBillingConfigReadResponse.


        :param show_renewal_date: The show_renewal_date of this OrganizationOrganizationBillingConfigReadResponse.  # noqa: E501
        :type show_renewal_date: bool
        """
        if self.local_vars_configuration.client_side_validation and show_renewal_date is None:  # noqa: E501
            raise ValueError("Invalid value for `show_renewal_date`, must not be `None`")  # noqa: E501

        self._show_renewal_date = show_renewal_date

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationOrganizationBillingConfigReadResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrganizationOrganizationBillingConfigReadResponse):
            return True

        return self.to_dict() != other.to_dict()
